@@ -1,4 +1,6 @@
 import logging
+import os
+import shutil
 import threading
 from typing import Optional
 
@@ -6,7 +8,8 @@ import zmq
 
 from openmodule.alert import AlertHandler
 from openmodule.config import validate_config_module
-from openmodule.health import HealthHandlerType, Healthz
+from openmodule.dispatcher import SubscribingMessageDispatcher
+from openmodule.health import HealthHandlerType, Healthz, HealthPingMessage
 from openmodule.logging import init_logging
 from openmodule.messaging import get_pub_socket, get_sub_socket, receive_message_from_socket
 from openmodule.models import ZMQMessage
@@ -19,23 +22,30 @@ class OpenModuleCore(threading.Thread):
         super().__init__(target=get_thread_wrapper(self._run))
         self.context = context
         self.config = config
+
         self.pub_lock = threading.Lock()
+        self.sub_lock = threading.Lock()
+
         self.pub_socket = get_pub_socket(self.context, self.config, linger=1000)
         self.sub_socket = get_sub_socket(self.context, self.config)
-        self.sub_socket.subscribe(b"healthz")
-        self.log = logging.getLogger(self.__class__.__name__)
+        self.messages = SubscribingMessageDispatcher(self._subscribe)
 
+        self.log = logging.getLogger(self.__class__.__name__)
         self.health = Healthz(self)
         self.alerts = AlertHandler(self)
 
+        self.messages.register_handler(b"healthz", HealthPingMessage, self.health.process_message,
+                                       filter={"type": "ping"})
+
+    def _subscribe(self, topic: bytes):
+        with self.sub_lock:
+            self.sub_socket.subscribe(topic)
+
     def _run(self):
         try:
             while True:
                 topic, message = receive_message_from_socket(self.sub_socket)
-                if message is None:
-                    continue
-                if topic == b"healthz":
-                    self.health.process_message(message)
+                self.messages.dispatch(topic, message)
         except zmq.ContextTerminated:
             self.log.debug("context terminated, core shutting down")
         finally:
@@ -50,7 +60,16 @@ class OpenModuleCore(threading.Thread):
 _core_thread: Optional[OpenModuleCore] = None
 
 
-def init_openmodule(config, sentry=True, logging=True,
+def init_dsgvo_config():
+    if os.path.exists("/data") and os.path.exists("/data/config.yml"):
+        shutil.copyfile("/data/config.yml", "/data/tmp.yml")
+        shutil.move("/data/tmp.yml", "/data/dsgvo-config.yml")
+    if os.path.exists("/data") and os.path.exists("dsgvo-default.yml"):
+        shutil.copyfile("dsgvo-default.yml", "/data/tmp.yml")
+        shutil.move("/data/tmp.yml", "/data/dsgvo-default.yml")
+
+
+def init_openmodule(config, sentry=True, logging=True, dsgvo=True,
                     health_handler: Optional[HealthHandlerType] = None,
                     context=None) -> OpenModuleCore:
     context = context or zmq.Context()
@@ -67,6 +86,9 @@ def init_openmodule(config, sentry=True, logging=True,
     if sentry:
         init_sentry(_core_thread)
 
+    if dsgvo:
+        init_dsgvo_config()
+
     if health_handler:
         _core_thread.health.health_handler = health_handler
 
