@@ -1,13 +1,11 @@
-import logging
 from typing import Optional, Dict, Any
+from typing import TYPE_CHECKING
 
 import sentry_sdk
 from sentry_sdk.transport import Transport
 
 from openmodule.models import ZMQMessage
 
-from typing import TYPE_CHECKING
-
 if TYPE_CHECKING:  # pragma: no cover
     from openmodule.core import OpenModuleCore
 
@@ -58,6 +56,8 @@ def init_sentry(core: 'OpenModuleCore', extras=None, **kwargs):
         with sentry_sdk.configure_scope() as scope:
             for key, value in extras.items():
                 scope.set_extra(key, value)
+    else:
+        core.log.info("not activating sentry because version is unknown")
 
 
 def should_activate_sentry(config) -> bool:
@@ -68,7 +68,6 @@ def should_activate_sentry(config) -> bool:
     :return: bool
     """
     if config.VERSION == "unknown":
-        logging.info("not activating sentry because version is unknown")
         return False
     return True
 
