@@ -1,12 +1,16 @@
 import logging
 import os
 import socket
+import tempfile
 import warnings
 from types import SimpleNamespace
 from unittest import TestCase
 
+from pydantic import ValidationError
+
 from openmodule import config
 from openmodule.config import validate_config_module
+from openmodule.models import OpenModuleModel
 
 
 class EnvTestCase(TestCase):
@@ -129,6 +133,38 @@ class ConfigTest(EnvTestCase):
         self.assertEqual("TEST123", config.resource())
 
 
+class ConfigYamlTest(EnvTestCase):
+    class ExampleModel(OpenModuleModel):
+        string: str = "default"
+
+    class NonConstructable(OpenModuleModel):
+        string: str
+
+    def test_path_from_env(self):
+        path = tempfile.mktemp()
+        try:
+            with open(path, "w") as f:
+                f.write("string: not-default")
+            self.env(path, "CONFIG_YAML")
+            instance = config.yaml(self.ExampleModel)
+            self.assertEqual('not-default', instance.string)
+        finally:
+            os.unlink(path)
+
+    def test_default_model(self):
+        instance = config.yaml(self.ExampleModel)
+        self.assertEqual("default", instance.string)
+
+    def test_invalid_default_model(self):
+        # we do not protect against any validation errors, but simply log them
+        # in any case this is mostly a developer's fault, and hardly ever a user fault
+        with self.assertRaises(ValidationError):
+            with self.assertLogs() as cm:
+                config.yaml(self.NonConstructable)
+
+        self.assertIn("wrong with the configuration", str(cm.output))
+
+
 class LegacyConfigSupportTest(EnvTestCase):
     def test_broker_pub(self):
         # nothing found -> defaults
